<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">

      <el-form-item label="实景三维名称" prop="tilesName">
        <el-input
          v-model="queryParams.tilesName"
          placeholder="请输入实景三维名称"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>

      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['tiles3d:tilesmap:add']"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['tiles3d:tilesmap:edit']"
        >修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['tiles3d:tilesmap:remove']"
        >删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          @click="handleExport"
          v-hasPermi="['tiles3d:tilesmap:export']"
        >导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="tilesmapList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label="ID" align="center" prop="tilesId">

      </el-table-column>
      <el-table-column label="实景三维名称" align="center" prop="tilesName">

      </el-table-column>
      <el-table-column label="实景三维路径" align="center" prop="tilesUrl">

      </el-table-column>
      <el-table-column label="是否默认加载ff默认初始化" align="center" prop="tilesType">

      </el-table-column>
      <el-table-column label="x轴偏移" align="center" prop="tilesX">

      </el-table-column>
      <el-table-column label="y轴偏移" align="center" prop="tilesY">

      </el-table-column>
      <el-table-column label="z轴偏移" align="center" prop="tilesZ">

      </el-table-column>
      <el-table-column label="相机坐标" align="center" prop="camPoi">

      </el-table-column>
      <el-table-column label="相机方位" align="center" prop="camHeading">

      </el-table-column>
      <el-table-column label="相机俯仰" align="center" prop="camPitch">

      </el-table-column>
      <el-table-column label="清晰度1" align="center" prop="maximumScreenSpaceError">

      </el-table-column>
      <el-table-column label="清晰度2" align="center" prop="maximumMemoryUsage">

      </el-table-column>
      <el-table-column label="清晰度3" align="center" prop="cullRequestsWhileMovingMultiplier">

      </el-table-column>
      <el-table-column label="清晰度4" align="center" prop="dynamicScreenSpaceErrorDensity">

      </el-table-column>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['tiles3d:tilesmap:edit']"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['tiles3d:tilesmap:remove']"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改三维实景管理对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="ID" prop="tilesId">
          <el-input v-model="form.tilesId" placeholder="请输入ID" />
        </el-form-item>
        <el-form-item label="实景三维名称" prop="tilesName">
          <el-input v-model="form.tilesName" placeholder="请输入实景三维名称" />
        </el-form-item>
        <el-form-item label="实景三维路径" prop="tilesUrl">
          <el-input v-model="form.tilesUrl" placeholder="请输入实景三维路径" />
        </el-form-item>
        <el-form-item label="是否默认加载ff默认初始化" prop="tilesType">
          <el-input v-model="form.tilesType" placeholder="请输入是否默认加载ff默认初始化" />
        </el-form-item>
        <el-form-item label="x轴偏移" prop="tilesX">
          <el-input v-model="form.tilesX" placeholder="请输入x轴偏移" />
        </el-form-item>
        <el-form-item label="y轴偏移" prop="tilesY">
          <el-input v-model="form.tilesY" placeholder="请输入y轴偏移" />
        </el-form-item>
        <el-form-item label="z轴偏移" prop="tilesZ">
          <el-input v-model="form.tilesZ" placeholder="请输入z轴偏移" />
        </el-form-item>
        <el-form-item label="相机坐标" prop="camPoi">
          <el-input v-model="form.camPoi" placeholder="请输入相机坐标" />
        </el-form-item>
        <el-form-item label="相机方位" prop="camHeading">
          <el-input v-model="form.camHeading" placeholder="请输入相机方位" />
        </el-form-item>
        <el-form-item label="相机俯仰" prop="camPitch">
          <el-input v-model="form.camPitch" placeholder="请输入相机俯仰" />
        </el-form-item>
        <el-form-item label="清晰度1" prop="maximumScreenSpaceError">
          <el-input v-model="form.maximumScreenSpaceError" placeholder="请输入清晰度1" />
        </el-form-item>
        <el-form-item label="清晰度2" prop="maximumMemoryUsage">
          <el-input v-model="form.maximumMemoryUsage" placeholder="请输入清晰度2" />
        </el-form-item>
        <el-form-item label="清晰度3" prop="cullRequestsWhileMovingMultiplier">
          <el-input v-model="form.cullRequestsWhileMovingMultiplier" placeholder="请输入清晰度3" />
        </el-form-item>
        <el-form-item label="清晰度4" prop="dynamicScreenSpaceErrorDensity">
          <el-input v-model="form.dynamicScreenSpaceErrorDensity" placeholder="请输入清晰度4" />
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listTilesmap, getTilesmap, delTilesmap, addTilesmap, updateTilesmap } from "@/api/tiles3d/tilesmap";

export default {
  name: "Tilesmap",
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 三维实景管理表格数据
      tilesmapList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        tilesId: null,
        tilesName: null,
        tilesUrl: null,
        tilesType: null,
        tilesX: null,
        tilesY: null,
        tilesZ: null,
        camPoi: null,
        camHeading: null,
        camPitch: null,
        maximumScreenSpaceError: null,
        maximumMemoryUsage: null,
        cullRequestsWhileMovingMultiplier: null,
        dynamicScreenSpaceErrorDensity: null
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
      }
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询三维实景管理列表 */
    getList() {
      this.loading = true;
      listTilesmap(this.queryParams).then(response => {
        this.tilesmapList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        tilesId: null,
        tilesName: null,
        tilesUrl: null,
        tilesType: null,
        tilesX: null,
        tilesY: null,
        tilesZ: null,
        camPoi: null,
        camHeading: null,
        camPitch: null,
        maximumScreenSpaceError: null,
        maximumMemoryUsage: null,
        cullRequestsWhileMovingMultiplier: null,
        dynamicScreenSpaceErrorDensity: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.tilesId)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加三维实景管理";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const tilesId = row.tilesId || this.ids
      getTilesmap(tilesId).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改三维实景管理";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.tilesId != null) {
            updateTilesmap(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addTilesmap(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const tilesIds = row.tilesId || this.ids;
      this.$modal.confirm('是否确认删除三维实景管理编号为"' + tilesIds + '"的数据项？').then(function() {
        return delTilesmap(tilesIds);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('tiles3d/tilesmap/export', {
        ...this.queryParams
      }, `tilesmap_${new Date().getTime()}.xlsx`)
    }
  }
};
</script>
